/*
 * menu_commands.c: A plugin for the Video Disk Recorder
 *
 * See the README file for copyright information and how to reach the author.
 *
 * $Id$
 */

#include "menu_dirselect.h"
#include "epgsearchext.h"

cDirExts DirExts;

// --- cMenuDirItem ---------------------------------------------------------
class cMenuDirItem : public cOsdItem 
{
 private:
    const char* directory;
    bool internal;
 public:
    cMenuDirItem(const char* text, bool intern) : cOsdItem(text) { directory = text; internal = intern;}
    virtual int Compare(const cListObject &ListObject) const;
};

int cMenuDirItem::Compare(const cListObject &ListObject) const
{
    cMenuDirItem *p = (cMenuDirItem *)&ListObject;
    if (internal != p->internal)
	return (internal?-1:1);
    return strcmp(directory, p->directory);	
}


// --- cMenuDirSelect ---------------------------------------------------------

cMenuDirSelect::cMenuDirSelect(char* szDirectory)
    :cOsdMenu(tr("Select directory"))
{
    Directory = szDirectory;
    cSearchExt *searchExt = SearchExts.First();
// add distinct directories from existing search timers
    while (searchExt) 
    {
	if (strlen(searchExt->directory) > 0)
	{
	    bool found = false;
	    for(int i=0; i<Count(); i++)
	    {
		const char* ItemText = Get(i)->Text();
		if (ItemText && strlen(ItemText) > 0 &&
		    strcmp(searchExt->directory, ItemText) == 0)
		{
		    found = true;
		    break;
		}
	    }
	    if (!found)
		Add(new cMenuDirItem(hk(searchExt->directory), true));
	}
	searchExt = SearchExts.Next(searchExt);
    }

    DirExts.Load(AddDirectory( cPlugin::ConfigDirectory(), "epgsearchdirs.conf"), true);
    cDirExt* DirExt = DirExts.First();
    if (DirExt)
	AddCategory("extern");
    while (DirExt) 
    {
	Add(new cMenuDirItem(hk(DirExt->Name()), false));	
	DirExt = DirExts.Next(DirExt);
    }

    Sort();
}

void cMenuDirSelect::AddCategory(const char *Title) 
{
  char *buffer = NULL;
  asprintf(&buffer, "--- %s -------------------------------------------------"
                "---------------", Title );

  cOsdItem *item = new cOsdItem(buffer);
  free(buffer);
  item->SetSelectable(false);
  Add(item);
}

eOSState cMenuDirSelect::ProcessKey(eKeys Key)
{
  eOSState state = cOsdMenu::ProcessKey(Key);

  if (state == osUnknown) {
     switch (Key) {
	 case kGreen:
	 case kYellow:
	 case kBlue:
	     return osContinue;
	 case kOk:  
	     strcpy(Directory,Get(Current())->Text());
	     return osBack;
       default:   break;
       }
     }
  return state;
}


